import static java.util.Arrays.deepToString;

import java.io.*;
import java.util.*;

public class xml_nn {

	static boolean checkForXML(String s) {
		if (s.indexOf(' ') >= 0) {
			throw new AssertionError();
		}
		List<String> stack = new ArrayList<String>();
		while (!s.isEmpty()) {
			if (s.charAt(0) != '<') {
				return false;
			}
			int p = s.indexOf('>');
			if (p < 0) {
				return false;
			}
			String d = s.substring(1, p);
			if (d.isEmpty()) {
				return false;
			}
			s = s.substring(p + 1);
			if (d.charAt(0) == '/') {
				d = d.substring(1);
				if (!isWord(d)) {
					return false;
				}
				if (stack.isEmpty() || !stack.get(stack.size() - 1).equals(d)) {
					return false;
				}
				stack.remove(stack.size() - 1);
			} else {
				if (!isWord(d)) {
					return false;
				}
				stack.add(d);
			}
		}
		return stack.isEmpty();
	}

	static boolean isWord(String s) {
		for (int i = 0; i < s.length(); i++) {
			if (!isAlpha(s.charAt(i))) {
				return false;
			}
		}
		return true;
	}

	static boolean isAlpha(char c) {
		return c >= 'a' && c <= 'z';
	}

	final static char[] ALPHABET;
	static {
		StringBuilder sb = new StringBuilder();
		for (int i = 0; i < 26; i++) {
			sb.appendCodePoint('a' + i);
		}
		sb.append('/').append('<').append('>');
		ALPHABET = sb.toString().toCharArray();
	}

	static boolean checkInput(String line) {
		String a = new String(ALPHABET);
		for (int i = 0; i < line.length(); i++) {
			char c = line.charAt(i);
			if (a.indexOf(c) < 0) {
				throw new AssertionError("invalid character in input: " + c);
			}
		}
		return true;
	}

	static void solve() throws Exception {
		String line = br.readLine();
		checkInput(line);
		char[] c = line.toCharArray();
		for (int i = 0; i < c.length; i++) {
			char cur = c[i];
			for (char e : ALPHABET) {
				c[i] = e;
				String xml = new String(c);
				if (checkForXML(xml)) {
					out.println(xml);
					return;
				}
			}
			c[i] = cur;
		}
		throw new AssertionError();
	}

	static BufferedReader br;
	static PrintWriter out;

	static void debug(Object... a) {
		System.err.println(deepToString(a));
	}

	public static void main(String[] args) {
		try {
			File file = new File("xml.in");
			InputStream input = System.in;
			OutputStream output = System.out;
			if (file.canRead()) {
				input = (new FileInputStream(file));
				output = (new PrintStream("xml.out"));
			}
			br = new BufferedReader(new InputStreamReader(input));
			out = new PrintWriter(output);
			solve();
			out.close();
			br.close();
		} catch (Throwable e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
}