#include <ctime>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>

#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <bitset>
#include <queue>
#include <deque>
#include <stack>
#include <map>
#include <set>

#define eprintf(...) fprintf(stderr, __VA_ARGS__)

using namespace std;

typedef long long ll;

const int maxn = 100000;

int n, p1[maxn], p2[maxn], cnt[maxn];

ll stress()
{
	ll ans = 0;
	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < n; j++) cnt[j] = 0;
		for (int j = i; j != -1; j = p1[j]) cnt[j]++;
		for (int j = i; j != -1; j = p2[j]) cnt[j]++;
		for (int j = 0; j < n; j++)
			if (cnt[j] == 2) ans++;
		ans--;
	}
	return ans;
}

struct tree
{
	vector<int> g[maxn];
	int tin[maxn], tout[maxn];
};

struct node
{
	int id, t1, t2;

	inline bool operator < (const node &v) const
	{
		return t2 < v.t2;
	}
};

inline bool compareT1(const node &a, const node &b)
{
	return a.t1 < b.t1;
}

const int halfSize = 131072, treeSize = halfSize << 1;

vector<int> stree[treeSize];
int timer = 0;
tree t1, t2;
node srtd[maxn];

void dfs(int v, tree &t)
{
	t.tin[v] = timer++;
	for (size_t i = 0; i < t.g[v].size(); i++)
		dfs(t.g[v][i], t);
	t.tout[v] = timer++;
}

void buildtree(int v, int tl, int tr)
{
	if (tl + 1 == tr)
	{
		if (tl < n) stree[v].push_back(srtd[tl].t2);
		return;
	}
	int m = (tl + tr) >> 1;
	buildtree((v << 1) + 1, tl, m);
	buildtree((v << 1) + 2, m, tr);
	stree[v].resize(stree[(v << 1) + 1].size() + stree[(v << 1) + 2].size());
	merge(stree[(v << 1) + 1].begin(), stree[(v << 1) + 1].end(),
		  stree[(v << 1) + 2].begin(), stree[(v << 1) + 2].end(),
		  stree[v].begin());
}

inline int ask(int v, int tl, int tr, int l, int r, int a, int b)
{
	if (l == tl && r == tr)
		return upper_bound(stree[v].begin(), stree[v].end(), b) - lower_bound(stree[v].begin(), stree[v].end(), a);
	int m = (tl + tr) >> 1;
	if (r <= m) return ask((v << 1) + 1, tl, m, l, r, a, b);
	if (l >= m) return ask((v << 1) + 2, m, tr, l, r, a, b);
	return ask((v << 1) + 1, tl, m, l, m, a, b) + ask((v << 1) + 2, m, tr, m, r, a, b);
}

ll solve()
{
	int r1 = -1, r2 = -1;
	for (int i = 0; i < n; i++)
		if (p1[i] != -1) t1.g[p1[i]].push_back(i);
		else r1 = i;
	for (int i = 0; i < n; i++)
		if (p2[i] != -1) t2.g[p2[i]].push_back(i);
		else r2 = i;
	dfs(r1, t1);
	dfs(r2, t2);
	for (int i = 0; i < n; i++)
		srtd[i].id = i,
		srtd[i].t1 = t1.tin[i],
		srtd[i].t2 = t2.tin[i];
	sort(srtd, srtd + n, compareT1);
	buildtree(0, 0, halfSize);
	ll ans = 0;
	for (int i = 0; i < n; i++)
	{
		int id = srtd[i].id, l = i;
		node x;
		x.t1 = t1.tout[id];
		int r = upper_bound(srtd, srtd + n, x, compareT1) - srtd;
		ans += ask(0, 0, halfSize, l, r, t2.tin[id], t2.tout[id]) - 1;
	}
	return ans;
}

void gen()
{
	freopen("virus.in", "w", stdout);
	int n = 100000;
	printf("%d\n", n);
	for (int t = 0; t < 2; t++, printf("\n"))
		for (int i = 0; i < n; i++)
		{
			if (i == 0) printf("0");
			else printf(" %d", rand() % i + 1);
		}

	fclose(stdout);
}

int main()
{
	freopen("virus.in", "r", stdin);
	freopen("virus.out", "w", stdout);
	scanf("%d", &n);
	for (int i = 0; i < n; i++)
		scanf("%d", &p1[i]), p1[i]--;
	for (int i = 0; i < n; i++)
		scanf("%d", &p2[i]), p2[i]--;
	printf("%lld\n", solve());
	return 0;
}