#include <cmath>
#include <ctime>
#include <cstdio>
#include <cstring>
#include <cstdlib>
#include <cassert>

#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <bitset>
#include <queue>
#include <deque>
#include <stack>
#include <map>
#include <set>

#define eprintf(...) fprintf(stderr, __VA_ARGS__)
#pragma comment(linker, "/STACK:67108864")

typedef long long ll;

using namespace std;

const int maxn = 100000, halfSize = 131072, treeSize = halfSize << 1;

int n, k, a[2][maxn], mintree[2][treeSize], maxtree[2][treeSize];

inline bool mless(int t, int x, int y)
{
	if (x >= n) return false;
	if (y >= n) return true;
	return a[t][x] < a[t][y];
}

inline bool mgr(int t, int x, int y)
{
	if (x >= n) return false;
	if (y >= n) return true;
	return a[t][x] > a[t][y];
}

void buildTree(int t, int v, int tl, int tr)
{
	if (tl + 1 == tr)
	{
		mintree[t][v] = tl;
		maxtree[t][v] = tl;
		return;
	}
	int m = (tl + tr) >> 1;
	buildTree(t, (v << 1) + 1, tl, m);
	buildTree(t, (v << 1) + 2, m, tr);
	mintree[t][v] = mless(t, mintree[t][(v << 1) + 1], mintree[t][(v << 1) + 2]) ? mintree[t][(v << 1) + 1] : mintree[t][(v << 1) + 2];
	maxtree[t][v] = mgr(t, maxtree[t][(v << 1) + 1], maxtree[t][(v << 1) + 2]) ? maxtree[t][(v << 1) + 1] : maxtree[t][(v << 1) + 2];
}

int getmin(int t, int v, int tl, int tr, int l, int r)
{
	if (l == tl && r == tr) return mintree[t][v];
	int m = (tl + tr) >> 1;
	if (r <= m) return getmin(t, (v << 1) + 1, tl, m, l, r);
	if (l >= m) return getmin(t, (v << 1) + 2, m, tr, l, r);
	int a = getmin(t, (v << 1) + 1, tl, m, l, m);
	int b = getmin(t, (v << 1) + 2, m, tr, m, r);
	return mless(t, a, b) ? a : b;
}

int getmax(int t, int v, int tl, int tr, int l, int r)
{
	if (l == tl && r == tr) return maxtree[t][v];
	int m = (tl + tr) >> 1;
	if (r <= m) return getmax(t, (v << 1) + 1, tl, m, l, r);
	if (l >= m) return getmax(t, (v << 1) + 2, m, tr, l, r);
	int a = getmax(t, (v << 1) + 1, tl, m, l, m);
	int b = getmax(t, (v << 1) + 2, m, tr, m, r);
	return mgr(t, a, b) ? a : b;
}

int main()
{
	freopen("mosaic.in", "r", stdin);
	freopen("mosaic.out", "w", stdout);
	scanf("%d", &n);
	for (int i = 0; i < n; i++)
		scanf("%d%d", &a[0][i], &a[1][i]);
	buildTree(0, 0, 0, halfSize);
	buildTree(1, 0, 0, halfSize);
	scanf("%d", &k);
	for (int i = 0; i < k; i++)
	{
		int l, r, good[4];
		scanf("%d%d", &l, &r), l--, r--;
		for (int q = 0; q < 2; q++)
		{
			good[2 * q] = getmax(q, 0, 0, halfSize, l, r + 1);
			good[2 * q + 1] = getmin(q, 0, 0, halfSize, l, r + 1);
		}
		int badx = -1, bady = -1;
		for (int j = 0; j < 4; j++)
			for (int z = j + 1; z < 4; z++)
				if (a[0][good[j]] != a[0][good[z]] && a[1][good[j]] != a[1][good[z]])
					badx = good[j], bady = good[z];
		printf("%d %d\n", badx + 1, bady + 1);
	}
	return 0;
}