import java.io.BufferedReader;
import java.io.FileReader;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.ArrayDeque;


public class Solution {
	private static BufferedReader reader;
	private static PrintWriter writer;
	
	private static String a, b;
	
	private static class Data {
		private int l1, r1, l2, r2;
		private BigInteger sum;
		
		public Data(int l1, int r1, int l2, int r2, BigInteger sum) {
			this.l1 = l1;
			this.r1 = r1;
			this.l2 = l2;
			this.r2 = r2;
			this.sum = sum;
		}
		
		public int compareSumToNum() {
			BigInteger num = new BigInteger(b.substring(l2, r2 + 1));
			
			return sum.compareTo(num);
		}
		
		public boolean areIndexesProper() {
			return (l1 == l2 && a.length() - r1 == b.length() - r2);
		}
		
		public Data shiftLeft1() {
			return new Data(l1 - 1, r1, l2, r2, sum.add(new BigInteger(a.substring(l1 - 1, l1))));
		}
		
		public Data shiftRight1() {
			return new Data(l1, r1 + 1, l2, r2, sum.add(new BigInteger(a.substring(r1 + 1, r1 + 2))));
		}
		
		public Data shiftLeft2() {
			return new Data(l1, r1, l2 - 1, r2, sum);
		}
		
		public Data shiftRight2() {
			return new Data(l1, r1, l2, r2 + 1, sum);
		}
	}
	
	private static int lcp() {
		int lcp = 0;
		
		int lim = Math.min(a.length(), b.length());
		for (int i = 0; i < lim; i++) {
			if (a.charAt(i) == b.charAt(i)) lcp++;
			else break;
		}
		
		return lcp;
	}
	
	private static int lcs() {
		int lcs = 0;
		
		for (int i = a.length() - 1, j = b.length() - 1; i >= 0 && j >= 0; i--, j--) {
			if (a.charAt(i) == b.charAt(j)) lcs++;
			else break;
		}
		
		return lcs;
	}	
	
	public static void main(String[] args) throws Exception {
		reader = new BufferedReader(new FileReader("password.in"));
		writer = new PrintWriter("password.out");

		a = reader.readLine();
		b = reader.readLine();
		
		int lcp = lcp();
		int lcs = lcs();
		
		if (lcp == lcs && lcp == a.length() && a.length() == b.length()) {
			writer.print("1 1");
			writer.close();
			return;
		}
		
		int l1 = Math.min(a.length() - 1, lcp);
		int r1 = Math.max(l1, a.length() - 1 - lcs);
		
		int l2 = Math.min(b.length() - 1, lcp);
		int r2 = Math.max(l2, b.length() - 1 - lcs);
		
		BigInteger sum = BigInteger.ZERO;
		
		for (int i = l1; i <= r1; i++) {
			sum = sum.add(new BigInteger(a.charAt(i) + ""));
		}
		
		ArrayDeque<Data> dq = new ArrayDeque<Solution.Data>();
		
		dq.addLast(new Data(l1, r1, l2, r2, sum));
		
		while (!dq.isEmpty()) {
			Data data = dq.pollLast();
			
			int compare = data.compareSumToNum();
			
			if (compare == 0 && data.areIndexesProper()) {
				writer.print(String.format("%d %d", data.l1 + 1, data.r1 + 1));
				writer.close();
				return;
			}
			
			//sum < num
		    if (compare < 0) {
		    	if (data.l1 > 0) {
		    		Data data1 = data.shiftLeft1();
		    		dq.addLast(data1);
		    	}
		    	if (data.r1 + 1 < a.length()) {
		    		Data data1 = data.shiftRight1();
		    		dq.addLast(data1);
		    	}
		    }
		    //sum > num
		    else {
		    	if (data.l2 > 0) {
		    		Data data1 = data.shiftLeft2();
		    		dq.addLast(data1);
		    	}
		    	if (data.r2 + 1 < b.length()) {
		    		Data data1 = data.shiftRight2();
		    		dq.addLast(data1);
		    	}
		    }
		}
		
		System.out.println("no answer");
	}

}
