import java.io.BufferedReader;
import java.io.FileReader;
import java.io.PrintWriter;
import java.math.BigInteger;
import java.util.ArrayDeque;


public class Solution {
	private static BufferedReader reader;
	private static PrintWriter writer;
	
	private static char[] a, b;
	
	private static class Data {
		private int l1, r1, l2, r2;
		private BigInteger sum, num;
		
		public Data(int l1, int r1, int l2, int r2, BigInteger sum, BigInteger num) {
			this.l1 = l1;
			this.r1 = r1;
			this.l2 = l2;
			this.r2 = r2;
			this.sum = sum;
			this.num = num;
		}
		
		public int compareSumToNum() {
			return sum.compareTo(num);
		}
		
		public boolean areIndexesProper() {
			return (l1 == l2 && a.length - r1 == b.length - r2);
		}
		
		public Data shiftLeft1() {
			return new Data(l1 - 1, r1, l2, r2, sum.add(new BigInteger(a[l1 - 1] + "")), num);
		}
		
		public Data shiftRight1() {
			return new Data(l1, r1 + 1, l2, r2, sum.add(new BigInteger(a[r1 + 1] + "")), num);
		}
		
		public Data shiftLeft2() {
			return new Data(l1, r1, l2 - 1, r2, sum, num.add(new BigInteger(b[l2 - 1] + "").multiply(BigInteger.TEN.pow(r2 - l2 + 1))));
		}
		
		public Data shiftRight2() {
			return new Data(l1, r1, l2, r2 + 1, sum, num.multiply(BigInteger.TEN).add(new BigInteger(b[r2 + 1] + "")));
		}
	}
	
	private static int lcp() {
		int lcp = 0;
		
		int lim = Math.min(a.length, b.length);
		for (int i = 0; i < lim; i++) {
			if (a[i] == b[i]) lcp++;
			else break;
		}
		
		return lcp;
	}
	
	private static int lcs() {
		int lcs = 0;
		
		for (int i = a.length - 1, j = b.length - 1; i >= 0 && j >= 0; i--, j--) {
			if (a[i] == b[j]) lcs++;
			else break;
		}
		
		return lcs;
	}	
	
	public static void main(String[] args) throws Exception {
		reader = new BufferedReader(new FileReader("password.in"));
		writer = new PrintWriter("password.out");

		a = reader.readLine().toCharArray();
		b = reader.readLine().toCharArray();
		
		int lcp = lcp();
		int lcs = lcs();
		
		if (lcp == lcs && lcp == a.length && a.length == b.length) {
			writer.print("1 1");
			writer.close();
			return;
		}
		
		int l1 = Math.min(a.length - 1, lcp);
		int r1 = Math.max(l1, a.length - 1 - lcs);
		
		int l2 = Math.min(b.length - 1, lcp);
		int r2 = Math.max(l2, b.length - 1 - lcs);
		
		BigInteger sum = BigInteger.ZERO;
		
		for (int i = l1; i <= r1; i++) {
			sum = sum.add(new BigInteger(a[i] + ""));
		}
		
		StringBuilder sb = new StringBuilder(r2 - l2 + 1);
		
		for (int i = l2; i <= r2; i++) sb.append(b[i]);
		
		BigInteger num = new BigInteger(sb.toString());
		sb = null;
		
		ArrayDeque<Data> dq = new ArrayDeque<Solution.Data>(100000);
		
		dq.addLast(new Data(l1, r1, l2, r2, sum, num));
		
		while (!dq.isEmpty()) {
			Data data = dq.pollFirst();
			
			int compare = data.compareSumToNum();
			
			if (compare == 0 && data.areIndexesProper()) {
				writer.print(String.format("%d %d", data.l1 + 1, data.r1 + 1));
				writer.close();
				return;
			}
			
			//sum < num
		    if (compare < 0) {
		    	if (data.l1 > 0) {
		    		dq.addLast(data.shiftLeft1());
		    	}
		    	if (data.r1 + 1 < a.length) {
		    		dq.addLast(data.shiftRight1());
		    	}
		    }
		    //sum > num
		    else {
		    	if (data.l2 > 0) {
		    		dq.addLast(data.shiftLeft2());
		    	}
		    	if (data.r2 + 1 < b.length) {
		    		dq.addLast(data.shiftRight2());
		    	}
		    }
		}
		
		System.out.println("no answer");
	}

}
