import java.io.BufferedReader;
import java.io.FileReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.StringTokenizer;


public class Solution {
	private static BufferedReader reader;
	private static PrintWriter writer;
	private static StringTokenizer st;
	
	private static int nextInt() {
		return Integer.parseInt(st.nextToken());
	}
	
	private static void initTokenizer() throws Exception {
		st = new StringTokenizer(reader.readLine());
	}
	
	private static class Element {
		private int width, height;
		
		public Element(int width, int height) {
			this.width = width;
			this.height = height;
		}
		
		public boolean isHarmonic(Element e) {
			return this.width == e.width || this.height == e.height;
		}
	}
	
	private static class Info {
		private int left, right;
		public final static Info badInfo = new Info(-1, -1) {
			@Override
			public boolean isGood() {
				return false;
			}
		};
		
		public Info(int left, int right) {
			this.left = left;
			this.right = right;
		}
		
		public boolean isInside(int l, int r) {
			return left >= l && right <= r;
		}
		
		public boolean isGood() {
			return true;
		}
		
		public static Info getBest(Info a, Info b) {
			if (a.isGood()) return a;
			return b;
		}
		
		@Override
		public String toString() {
			return (left + 1) + " " + (right + 1);
		}
	}
	
	private static class Tree {
		private Element[] data;
		
		private Info[] tree;
		
		private ArrayList<Info> help;
		private ArrayList<Info> noans;
		
		private final static int sz = 25000;
		
		public Tree(Element[] data) {
			this.data = data;
			
			this.tree = new Info[(data.length << 2) + 1];
			
			this.help = new ArrayList<Solution.Info>(sz);
			this.noans = new ArrayList<Solution.Info>(sz);
			
			this.initNode(0, 0, data.length - 1);
		}
		
		private Info getInRange (int l1, int r1, int l2, int r2) {
			for (int i = l1; i <= r1; i++) {
				for (int j = l2; j <= r2; j++) {
					if (!data[i].isHarmonic(data[j])) {
						return new Info(i, j);
					}
				}
			}
			
			return Info.badInfo;
		}
		
		private void initNode(int node, int l, int r) {
			if (l == r) {
				tree[node] = Info.badInfo;
				return;
			}
			
			int mid = (l + r) >> 1;
			
			int ch1 = (node << 1) + 1;
			int ch2 = ch1 + 1;
			
			initNode(ch1, l, mid);
			initNode(ch2, mid  + 1, r);
			
			if (tree[ch1].isGood()) {
				tree[node] = tree[ch1];
				return;
			}
			else if (tree[ch2].isGood()) {
				tree[node] = tree[ch2];
				return;
			}
						
			tree[node] = getInRange(l, mid, mid + 1, r);
		}
		
		public Info getInfo(int l, int r) {
			for (Info check : help) {
				if (check.isInside(l, r)) {
					//System.out.println("use1");
					return check;
				}
			}
			for (Info no : noans) {
				if (l >= no.left && r <= no.right) {
					//System.out.println("use2");
					return Info.badInfo;
				}
			}
			
			Info info = this.getInfo(0, l, r, 0, data.length - 1);
			
			if (info.isGood() && help.size() <= sz) {
				help.add(info);
			}
			else if (!info.isGood() && noans.size() <= sz) {
				noans.add(new Info(l, r));
			}
			
			return info;
		}
		
		private Info getInfo(int node, int l, int r, int lborder, int rborder) {
			if (l == lborder && r == rborder) {
				return tree[node];
			}
			
			int ch1 = (node << 1) + 1;
			int ch2 = ch1 + 1;
			
			int mid = (lborder + rborder) >> 1;
			
			if (l > mid) {
				return this.getInfo(ch2, l, r, mid + 1, rborder);
			}
			
			if (r <= mid) {
				return this.getInfo(ch1, l, r, lborder, mid);
			}
			
			Info info = getInfo(ch1, l, mid, lborder, mid);
			info = Info.getBest(info, getInfo(ch2, mid + 1, r, mid + 1, rborder));
			
			if (!info.isGood()) {
				info = getInRange(l, mid, mid + 1, r);
			}
			
			return info;
		}
	}
	
	public static void main(String[] args) throws Exception {
		reader = new BufferedReader(new FileReader("mosaic.in"));
		writer = new PrintWriter("mosaic.out");
		
		initTokenizer();
		int n = nextInt();
		
		Element[] data = new Element[n];
		
		for (int i = 0; i < n; i++) {
			initTokenizer();
			
			data[i] = new Element(nextInt(), nextInt());
		}
		
		Tree tree = new Tree(data);
		
		initTokenizer();
		int k = nextInt();
		
		for (int i = 0; i < k; i++) {
			initTokenizer();
			
			int l = nextInt() - 1;
			int r = nextInt() - 1;
			
			Info info = tree.getInfo(l, r);
			
			writer.println(info.toString());
		}
		
		writer.close();
	}

}
