import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.Random;
import java.util.StringTokenizer;


public class Solution {
	private static BufferedReader reader;
	private static PrintWriter writer;
	private static StringTokenizer st;
	
	private static Random random = new Random();
	
	private static int nextRandom(int a, int b) {
		return random.nextInt(b - a + 1) + a;
	}
	
	private static int nextInt() {
		return Integer.parseInt(st.nextToken());
	}
	
	private static byte nextByte() {
		return Byte.parseByte(st.nextToken());
	}
	
	private static void initTokenizer() throws Exception {
		st = new StringTokenizer(reader.readLine());
	}
	
	private static class Point {
		private int x, y;
		
		public Point(int x, int y) {
			this.x = x;
			this.y = y;
		}
		
		@Override
		public Point clone() {
			return new Point(x, y);
		}
	}
	
	private static class Size {
		private int width, height;
		
		public Size(int width, int height) {
			this.width = width;
			this.height = height;
		}
	}
	
	private static class Field {
		private int x1, y1, x2, y2;
		
		public Field(int x1, int y1, int x2, int y2) {
			this.x1 = x1;
			this.x2 = x2;
			this.y1 = y1;
			this.y2 = y2;
		}
		
		public void offerPoint(int x, int y) {
			x1 = Math.min(x1, x);
			y1 = Math.min(y1, y);
			
			x2 = Math.max(x2, x);
			y2 = Math.max(y2, y);
		}
		
		public Size getSize() {
			return new Size(x2 - x1 + 1, y2 - y1 + 1);
		}
		
		public Field getPossibleLeftUpRange(int width, int height) {
			Size sz = this.getSize();
			
			return new Field(0, 0, width - sz.width, height - sz.height);
		}
		
		public Field applyOffset(int dx, int dy) {
			x1 += dx;
			x2 += dx;
			y1 += dy;
			y2 += dy;
			
			return this;
		}
		
		public Point getRel(int fromx, int fromy) {
			int randx = (x1 + x2) >> 1;
			int randy = (y1 + y2) >> 1;
			
			int dx = (int)Math.signum(randx - fromx);
			int dy = (int)Math.signum(randy - fromy);
			
			return new Point(dx, dy);
		}
		
		@Override
		public String toString() {
			return String.format("Range: %d, %d -> %d, %d", x1, y1, x2, y2);
		}
	}
	
	private static int n, m;
	
	private static void report(int dx, int dy) {
		System.out.println(String.format("%d %d 1", dx, dy));
		System.out.flush();
	}
	
	private static byte[] get() throws Exception {
		initTokenizer();
		
		byte here = nextByte();
		byte horseDx = nextByte();
		byte horseDy = nextByte();
		
		return new byte[] { here, horseDx, horseDy };
	}
	
	private static boolean isGood(int x, int y) {
		return (x >= 0 && y >= 0 && x < m && y < n);
	}
	
	public static void main(String[] args) throws Exception {
		reader = new BufferedReader(new InputStreamReader(System.in));
		
		initTokenizer();
		n = nextInt();
		m = nextInt();
		
		initTokenizer();
		int x0 = nextInt() - 1;
		int y0 = nextInt() - 1;
		
		Field fhorse = new Field(0, 0, 0, 0);
		
		int hdx = 0;
		int hdy = 0;
		
		int dy = 0;
		int dx = 0;
		
		report(dx, dy);
		
		while (true) {
			byte[] input = get();
			
			if (input[0] == 1) return;
			
			int horsedx = input[1];
			int horsedy = input[2];
			
			hdx += horsedx;
			hdy += horsedy;
			
			fhorse.offerPoint(hdx, hdy);
			
			Field range = fhorse.getPossibleLeftUpRange(m, n).
					applyOffset(hdx - fhorse.x1, hdy - fhorse.y1);
			
			//System.out.println(range);
			
			Point dpos = range.getRel(x0, y0);
			
			if (isGood(x0 + dpos.x, y0 + dpos.y)) {
				x0 += dpos.x;
				y0 += dpos.y;
				
				report(dpos.x, dpos.y);
			}
			else {
				dx = nextRandom(-1, 1);
				dy = nextRandom(-1, 1);
				
				if (isGood(x0 + dx, y0 + dy)) {
					x0 += dx;
					y0 += dy;
					
					report(dx, dy);
				}
				else {
					report(0, 0);
				}
			}
		}
	}

}
