#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <algorithm>

const int maxN = 100005;

int w[maxN];
int h[maxN];

enum HarmonyType {
	A_HARMONY = 0,    // a points to width harmony cell, b and c point to two different height cells
	B_HARMONY,    // a points to height harmony cell, b and c point to two different width cells
	SINGLE_ELEMENT,  // a points to single element
	ERROR // a and b point to erroneous pair
};

struct Eset {
	HarmonyType type;

	// a, b, c - positions

	int a, b;
	//int c;
};

Eset FromNumber(int xPos) {
	Eset f = { SINGLE_ELEMENT, xPos, 0 };
	return f;
}

bool IfError(int a, int b) {
	return !(w[a] == w[b] || h[a] == h[b]);
}

Eset Error(int a, int b) {
	//if(!IfError(a, b))
	//	printf("!!!");

	Eset e = { ERROR, a, b };
	return e;
}

Eset Unify(Eset a, Eset b) {
	if(b.type == SINGLE_ELEMENT)
		std::swap(a, b);

	if(a.type == A_HARMONY) {
		if(b.type == A_HARMONY) {
			if(w[a.a] != w[b.a]) {
				if(IfError(a.a, b.a))
					return Error(a.a, b.a);
				else
					return Error(a.a, b.b);

				/*if(h[a.a] == h[b.a])
					return Error(a.a, b.b);
				else
					return Error(a.a, b.a);*/
			} else return a;
		} else {
			// A_HARMONY & B_HARMONY

			if(IfError(a.a, b.a))
				return Error(a.a, b.a);
			else if(IfError(a.a, b.b))
				return Error(a.a, b.b);
			else if(IfError(a.b, b.a))
				return Error(a.b, b.a);
			else
				return Error(a.b, b.b);
		}
	} else if(a.type == B_HARMONY) {
		if(b.type == B_HARMONY) {
			if(h[a.a] != h[b.a]) {
				if(IfError(a.a, b.a))
					return Error(a.a, b.a);
				else
					return Error(a.a, b.b);

				/*if(h[a.a] == h[b.a])
					return Error(a.a, b.b);
				else
					return Error(a.a, b.a);*/
			} else return a;
		} else {
			// A_HARMONY & B_HARMONY

			if(IfError(a.a, b.a))
				return Error(a.a, b.a);
			else if(IfError(a.a, b.b))
				return Error(a.a, b.b);
			else if(IfError(a.b, b.a))
				return Error(a.b, b.a);
			else
				return Error(a.b, b.b);
		}
	} else {
		// SINGLE_ELEMENT & something

		if(b.type == A_HARMONY) {
			if(w[a.a] == w[b.a])
				return b;
			else {
				if(IfError(a.a, b.a))
					return Error(a.a, b.a);
				else
					return Error(a.a, b.b);
			}
		} else if(b.type == B_HARMONY) {
			if(h[a.a] == h[b.a])
				return b;
			else {
				if(IfError(a.a, b.a))
					return Error(a.a, b.a);
				else
					return Error(a.a, b.b);
			}
		} else {
			// Unify two single pairs

			if(IfError(a.a, b.a)) {
				return Error(a.a, b.a);
			} else if(w[a.a] == w[b.a]) {
				if(h[a.a] == h[b.a])
					return a;
				else {
					Eset aHarmony = { A_HARMONY, a.a, b.a };
					return aHarmony;
				}
			} else {
				// hs equal, ws not equal

				{
					Eset bHarmony = { B_HARMONY, a.a, b.a };
					return bHarmony;
				}
			}
		}
	}
}

const int maxStreeSize = 300000;

Eset segmentTree[maxStreeSize];

/*void Initialize() {
	for(int i = 0; i < maxStreeSize; i++) {
		segmentTree[i].type = SINGLE_ELEMENT;
		segmentTree[i].
	}
}

void Update() {
}*/

void PrintTree() {
	for(int i = 0; i < 8; i++)
		printf("%i: type: %i, %i %i\n", i, segmentTree[i].type, segmentTree[i].a, segmentTree[i].b);
}

void MassUpdate(int t, int l, int r) {
	if(l == r) {
		//printf("%i set to %i\n", t, l);

		segmentTree[t] = FromNumber(l);

		//printf("NOW %i\n", segmentTree[t].a);
	} else {
		int m = (l + r) / 2;

		MassUpdate(t * 2 + 1, l, m);
		MassUpdate(t * 2 + 2, m + 1, r);

		segmentTree[t] = Unify(segmentTree[t * 2 + 1], segmentTree[t * 2 + 2]);
	}
}

bool Intersects(int a, int b, int c, int d) {
	return (c >= a && c <= b) || (d >= a && d <= b);
}

Eset Query(int t, int l, int r, int x, int y) {
	//printf("Query(%i;   %i; %i;   %i; %i)\n", t, l, r, x, y);

	if(l >= x && r <= y) {
		//printf("Returning %i.\n", t);
		return segmentTree[t];
	} else {
		int m = (l + r) / 2;

		bool first = false;

		Eset result;

		if(Intersects(l, m, x, y)) {
			result = Query(t * 2 + 1, l, m, x, y);
			first = true;
		}

		if(Intersects(m + 1, r, x, y)) {
			if(!first) {
				result = Query(t * 2 + 2, m + 1, r, x, y);
			} else {
				Eset second = Query(t * 2 + 2, m + 1, r, x, y);
				result = Unify(result, second);
			}
		}

		//printf("Returning %i   %i %i\n", result.type, result.a, result.b);

		return result;
	}
}

int main() {
	freopen("mosaic.in" , "r", stdin);
	freopen("mosaic.out", "w", stdout);

	int N;
	scanf("%i", &N);

	for(int i = 1; i <= N; i++)
		scanf("%i %i", &w[i], &h[i]);

	MassUpdate(0, 1, N);

	//PrintTree();

	int K = 0;
	scanf("%i", &K);

	for(int i = 0; i < K; i++) {
		int l, r;
		scanf("%i %i", &l, &r);

		Eset x = Query(0, 1, N, l, r);

		if(x.type != ERROR)
			printf("0 0\n");
		else
			printf("%i %i\n", x.a, x.b);

		/*printf("type %i\n", x.type);

		printf("done.\n");*/
	}

	return 0;
}
