#include <cstdio>
#include <cstdlib>
#include <cassert>
#include <cstring>
#include <ctime>
#include <algorithm>
#include <vector>
#include <map>
#include <set>
#include <deque>

using namespace std;

#define mp make_pair
#define pb push_back
#define eprintf(...) fprintf(stderr, __VA_ARGS__)
#define sz(x) ((int)(x).size())
#define TASKNAME "mosaic"

typedef long long ll;
typedef vector<ll> vll;
typedef vector<int> vi;
typedef vector<vi> vvi;
typedef vector<bool> vb;
typedef vector<vb> vvb;
typedef pair<int, int> pii;

const int INF = 1e9;
class segm_tree {
  vector<pii> tr;
  int off;

  public:
  segm_tree(const vi &vals) {
    off = 1; while (off < sz(vals)) off <<= 1;
    tr = vector<pii>(2 * off, mp(INF, INF));
    for (int i = 0; i < sz(vals); i++)
      tr[off + i] = mp(vals[i], i);
    for (int i = off - 1; i >= 1; i--)
      tr[i] = min(tr[2 * i], tr[2 * i + 1]);
  }
  pii get(int l, int r) {
    l += off; r += off;

    pii res(INF, INF);
    while (l <= r) {
      if (l & 1) res = min(res, tr[l++]);
      if (!(r & 1)) res = min(res, tr[r--]);
      l >>= 1; r >>= 1;
    }
    return res;
  }
};

vvi poses;

inline int getPref(int R, int id) {
  const vi &cps = poses[id];
  return upper_bound(cps.begin(), cps.end(), R) - cps.begin();
}
inline int getPrefSum(int R, const pii &bad, int badid) {
  return getPref(R, bad.first) + getPref(R, bad.second) - getPref(R, badid);
}

int main() {
  freopen(TASKNAME ".in", "r", stdin);
  freopen(TASKNAME ".out", "w", stdout);

  int n;
  while (scanf("%d", &n) >= 1) {
    vector<pii> els(n);
    vi as;
    for (int i = 0; i < n; i++) {
      scanf("%d%d", &els[i].first, &els[i].second);
      els[i].first *= 2;
      els[i].second *= 2; els[i].second++;

      as.pb(els[i].first);
      as.pb(els[i].second);
    }

    sort(as.begin(), as.end());
    as.erase(unique(as.begin(), as.end()), as.end());

    for (int i = 0; i < n; i++) {
      els[i].first = lower_bound(as.begin(), as.end(), els[i].first) - as.begin();
      els[i].second = lower_bound(as.begin(), as.end(), els[i].second) - as.begin();
    }
    vector<pii> nids = els;
    sort(nids.begin(), nids.end());
    nids.erase(unique(nids.begin(), nids.end()), nids.end());

    vi elnid(n);
    for (int i = 0; i < n; i++)
      elnid[i] = sz(as) + lower_bound(nids.begin(), nids.end(), els[i]) - nids.begin();

    poses = vvi(sz(as) + sz(nids));
    for (int i = 0; i < n; i++) {
      poses[els[i].first].pb(i);
      poses[els[i].second].pb(i);
      poses[elnid[i]].pb(i);
    }

    vi ne(n, n);
    for (int i = 0; i < n; i++) {
      pii bad = els[i];
      int badid = elnid[i];

      int off = getPrefSum(i, bad, badid) - i;
      // X - off <= R - L
      // X <= R (- L + off)

      if (getPrefSum(n - 1, bad, badid) >= n - 1 + off) continue;

      int L = i, R = n - 1;
      while (L + 1 < R) {
        int M = (L + R) >> 1;
        if (getPrefSum(M, bad, badid) < M + off) R = M;
        else L = M;
      }
      ne[i] = R;
    }

    if (n <= 5000) {
      for (int a = 0; a < n; a++) {
        int b = a + 1;
        while (b < n && (els[a].first == els[b].first || els[a].second == els[b].second))
          b++;
        assert(ne[a] == b);
      }
    }

    int k;
    scanf("%d", &k);
    segm_tree tr(ne);
    for (int i = 0; i < k; i++) {
      int l, r;
      scanf("%d%d", &l, &r), l--, r--;

      pii res = tr.get(l, r);
      if (res.first > r) {
        printf("0 0\n");
      } else
        printf("%d %d\n", res.first + 1, res.second + 1);
    }
  }
  return 0;
}
