#include <cstdio>
#include <cstdlib>
#include <cassert>
#include <cstring>
#include <ctime>
#include <algorithm>
#include <vector>
#include <map>
#include <set>
#include <deque>

using namespace std;

#define mp make_pair
#define pb push_back
#define eprintf(...) fprintf(stderr, __VA_ARGS__)
#define sz(x) ((int)(x).size())
#define TASKNAME "mosaic"

typedef long long ll;
typedef vector<ll> vll;
typedef vector<int> vi;
typedef vector<vi> vvi;
typedef vector<bool> vb;
typedef vector<vb> vvb;
typedef pair<int, int> pii;

const int INF = 1e9;

const int MAXN = 100000;
const int MAXK = 350;
const int MAXA = 2 * MAXN;
const int MAXT = (MAXA + MAXK) / MAXK;

int nids[MAXN];
int trs[MAXT][MAXN];
int trts[MAXT];

pii sufs[MAXN];

int main() {
  freopen(TASKNAME ".in", "r", stdin);
  freopen(TASKNAME ".out", "w", stdout);

  int n;
  while (scanf("%d", &n) >= 1) {
    eprintf("mem=%d\n", sizeof(trs) / 1024 / 1024);
    vector<pii> els(n);
    vi as(2 * n);
    for (int i = 0; i < n; i++) {
      scanf("%d%d", &els[i].first, &els[i].second);
      as[2 * i] = els[i].first *= 2;
      as[2 * i + 1] = els[i].second = els[i].second * 2 + 1;
    }
    eprintf("readat %d\n", clock());
    sort(as.begin(), as.end());
    as.erase(unique(as.begin(), as.end()), as.end());

    vi cnts(sz(as));
    for (int i = 0; i < n; i++) {
      els[i].first = lower_bound(as.begin(), as.end(), els[i].first) - as.begin();
      els[i].second = lower_bound(as.begin(), as.end(), els[i].second) - as.begin();

      cnts[els[i].first]++;
      cnts[els[i].second]++;
    }
    
    {
      vector<pii> nels = els;
      sort(nels.begin(), nels.end());
      nels.erase(unique(nels.begin(), nels.end()), nels.end());

      vi las(n, n);
      for (int i = n - 1; i >= 0; i--) {
        int cid = lower_bound(nels.begin(), nels.end(), els[i]) - nels.begin();
        nids[i] = las[cid];
        las[cid] = i;
      }
    }

    vi ne1(n, n), ne2(n, n);
    for (int i = n - 2; i >= 0; i--)
      ne1[i] = els[i].first == els[i + 1].first ? ne1[i + 1] : i + 1;
    for (int i = n - 2; i >= 0; i--)
      ne2[i] = els[i].second == els[i + 1].second ? ne1[i + 1] : i + 1;

    int off = 1;
    while (off < n) off <<= 1;

    eprintf("precalcat %d\n", clock());
    int tcnt = 0;

    for (int i = 0; i < sz(as); i++) if (cnts[i] > MAXK) {
      trts[tcnt] = i;

      int cval = 0;
      for (int i2 = 0; i2 < n; i2++) {
        if (els[i2].first == i || els[i2].second == i)
          cval++;
        trs[tcnt][i2] = cval;
      }
      tcnt++;
    }
    eprintf("treesf_cnt= %d\n", tcnt);

    eprintf("start %d\n", clock());

    vi ne(n, n);
    for (int i = n - 1; i >= 0; i--) {
      if (cnts[els[i].first] <= MAXK || cnts[els[i].second] <= MAXK) {
        int b = i + 1;
        while (b < n)
          if (els[i].first == els[b].first) b = ne1[b];
          else if (els[i].second == els[b].second) b = ne2[b];
          else break;
        ne[i] = b;
      } else {
        int nid = nids[i];

        const int t1i = lower_bound(trts, trts + tcnt, els[i].first) - trts;
        const int t2i = lower_bound(trts, trts + tcnt, els[i].second) - trts;
        const int *t1 = trs[t1i];
        const int *t2 = trs[t2i];

        int L = i, R = nid - 1;
        int off = t1[L] + t2[L] - L;

        if (L < R && (t1[R] + t2[R] < R + off)) {
          while (L + 1 < R) {
            int M = (L + R) >> 1;
            if (t1[M] + t2[M] < M + off) R = M;
            else L = M;
          }
          ne[i] = min(ne[i], R);
        }
      }
    }
    eprintf("done %d\n", clock());

    if (n <= 5000) {
      for (int a = 0; a < n; a++) {
        int b = a + 1;
        while (b < n && (els[a].first == els[b].first || els[a].second == els[b].second))
          b++;
        assert(ne[a] == b);
      }
    }

    int k;
    scanf("%d", &k);
    pii cval(INF, INF);
    for (int i = n - 1; i >= 0; i--) {
      cval = min(cval, mp(ne[i], i));
      sufs[i] = cval;
    }
    for (int i = 0; i < k; i++) {
      int l, r;
      scanf("%d%d", &l, &r), l--, r--;

      pii res = sufs[l];
      if (res.first > r) {
        puts("0 0");
      } else
        printf("%d %d\n", res.first + 1, res.second + 1);
    }
    eprintf("finishat %d\n", clock());
  }
  return 0;
}
