#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <string>
#include <cstring>
#include <vector>
#include <ctime>

using namespace std;

#define FOR(a, b) for(int a = 0; a < (b); ++a)
#define clr(a) memset(a, 0, sizeof(a))

typedef long long ll;
const ll INF = ((ll)1000000000) * 1000000000;
const int MAXN = 100003;

struct dtree {
    dtree * l,* r;
    int x;
    ll y;
    int sz;
};

dtree mem[MAXN];
int _free = 0;

void upd(dtree * rt) {
    if (rt == NULL)
        return;
    rt->sz = 1;
    if (rt->l != NULL) {
        rt->sz += rt->l->sz;
    }
    if (rt->r != NULL) {
        rt->sz += rt->r->sz;
    }
    return;
}

void split(dtree * rt, int x, dtree *& l, dtree *& r) {
    if (rt == NULL) {
        r = NULL;
        l = NULL;
        return;
    }
    dtree *wl, *wr;
    if (rt->x < x) {
        split(rt->r, x, wl, wr);
        rt->r = wl;
        l = rt;
        r = wr;
    } else {
        split(rt->l, x, wl, wr);
        rt->l = wr;
        l = wl;
        r = rt;
    }
    upd(rt);
}

dtree * merge(dtree *wl, dtree * wr) {
    if (wl == NULL)
        return wr;
    if (wr == NULL)
        return wl;
    dtree *l = wl;
    dtree *r = wr;
    if (r->x < l->x)
        swap(l, r);
    if (l->y > r->y) {
        l->r = merge(l->r, r);
        upd(l);
        return l;
    } else {
        r->l = merge(l, r->l);
        upd(r);
        return r;
    }
}

dtree * add(dtree * rt, int x) {
    dtree * w = &mem[_free++];
    w->x = x;
    w->sz = 1;
    w->y = ((ll)rand()) * rand();
    w->l = NULL;
    w->r = NULL;
    dtree * wl, *wr;
    split(rt, x, wl, wr);
    return merge(merge(wl, w), wr);
}

int get(dtree *&rt, int l, int r) {
    if (rt == NULL)
        return 0;
    dtree *wl, *wr;
    split(rt, l, wl, wr);
    dtree *wl1, *wr1;
    split(wr, r, wl1, wr1);
    int w = 0;
    if (wl1 != NULL)
        w = wl1->sz;
    rt = merge(wl, merge(wl1, wr1));
    return w;
}

vector<int> e1[MAXN];
vector<int> e2[MAXN];
int tin[MAXN];
int tout[MAXN];
int t = 0;
dtree * d[MAXN];

void setT2(int v) {
    tin[v] = t;
    FOR(i, e2[v].size()) {
        t++;
        setT2(e2[v][i]);
        t++;
    }
    tout[v] = t;
    return;
}

ll ans = 0;

void dfs(int v) {
    d[v] = NULL;
    FOR(i, e1[v].size()) {
        int v1 = e1[v][i];
        dfs(v1);
        d[v] = merge(d[v], d[v1]);
    }
    ans += get(d[v], tin[v], tout[v]);
    d[v] = add(d[v], tin[v]);
    return;
}

int main() {
    srand(time(NULL));
    freopen("virus.in", "r", stdin);
    freopen("virus.out", "w", stdout);
    int n;
    scanf("%d", &n);
    int rt1, rt2;
    FOR(i, n) {
        int p;
        scanf("%d", &p);
        p--;
        if (p != -1)
            e1[p].push_back(i);
        else
            rt1 = i;
    }
    FOR(i, n) {
        int p;
        scanf("%d", &p);
        p--;
        if (p != -1)
            e2[p].push_back(i);
        else
            rt2 = i;
    }
    setT2(rt2);
    dfs(rt1);
    cout << ans;
    return 0;
}

