#pragma comment(linker, "/STACK:200000000")

#include <iostream>
#include <cassert>
#include <ctime>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <map>
#include <set>
#include <algorithm>
using namespace std;

const int INF = 2e9;

struct SegmentTree {
	vector<int> v;
	vector<int> values;
	inline void init(vector<int> &x) {
		int N = 1;
		while (N < x.size())
			N <<= 1;
		N <<= 1;
		v.resize(N);
		int sz = N >> 1;
		values.assign(sz + 1, INF);
		for (int i = 0; i < x.size(); i++)
			values[i] = x[i];

		for (int i = sz; i < N; i++)
			v[i] = i - sz;

		for (int i = sz - 1; i >= 1; i--) {
			if (values[v[2 * i]] < values[v[2 * i + 1]])
				v[i] = v[2 * i];
			else
				v[i] = v[2 * i + 1];
		}
	}

	int gt(int l, int r, int L, int R, int u) {
		if (r <= L || R <= l)
			return INF;
		if (l <= L && R <= r)
			return v[u];
		int val1 = gt(l, r, L, (L + R) >> 1, (u << 1));
		int val2 = gt(l, r, (L + R) >> 1, R, (u << 1) + 1);

		if (val1 == INF || val2 == INF) {
			if (val1 == INF)
				return val2;
			else
				return val1;
		}

		if (values[val1] < values[val2])
			return val1;
		else
			return val2;
	}

	inline int getMin(int l, int r) {
		return gt(l, r + 1, 1, (v.size() >> 1) + 1, 1);
	}

	inline int get(int x) {
		return values[x];
	}
};

typedef vector<int>::iterator viter;

const int MAXN = 100100;
const int MAGIC = 500;

int N, K;
int A[MAXN], B[MAXN];
int N1[MAXN], N2[MAXN];

int d[MAXN];

map<int, vector<int> > v, v2;
map<pair<int, int>, vector<int> > vp;

inline bool similar(const int &a, const int &b) {
	return (A[a] == A[b] || B[a] == B[b]);
}

void calcD() {
	for (int i = 0; i < N; i++) {
		d[i] = INF;
		for (int j = i + 1; j < N; j++) {
			if (!similar(i, j)) {
				d[i] = j;
				break;
			}
		}
	}
}

void foolSolution() {
	calcD();
	for (int i = 0; i < K; i++) {
		bool flag = false;
		for (int j = N1[i]; j < N2[i]; j++) {
			if (d[j] <= N2[i]) {
				printf("%d %d\n", j + 1, d[j] + 1);
				flag = true;
				break;
			}
		}
		if (!flag) {
			puts("0 0");
		}
	}
}

SegmentTree st;
vector<int> tmp;

void cleverSolution() {
	for (int i = 0; i < N; i++) {
		v[A[i]].push_back(i);
		v2[B[i]].push_back(i);
		vp[make_pair(A[i], B[i])].push_back(i);
	}

	int l, r, res;
	for (int i = N - 1; i >= 0; i--) {		
		d[i] = INF;
		bool ff = false;
		for (int j = 1; j < MAGIC && j + i < N; j++) {
			if (!similar(i, i + j)) {
				d[i] = i + j;
				break;
			} else {
				if (A[i] == A[i + j] && B[i] == B[i + j]) {
					d[i] = d[i + j];
					ff = true;
					break;
				}
				int u = d[i + j];
				if (u != INF && !similar(i, u) && d[i] > u) {
					d[i]= u;
				}
			}
		}

		/*if (i + MAGIC >= N)
			continue;

		if (d[i] == INF && !ff) {
			vector<int> &f = v[A[i]];
			vector<int> &s = v2[B[i]];
			vector<int> &p = vp[make_pair(A[i], B[i])];

			viter ff = lower_bound(f.begin(), f.end(), i);
			viter fs = lower_bound(s.begin(), s.end(), i);
			viter fp = lower_bound(p.begin(), p.end(), i);

			l = i + MAGIC, r = N;
			while (l < r - 1) {
				res = (l + r) >> 1;
				int valf = upper_bound(f.begin(), f.end(), res) - ff;
				int vals = upper_bound(s.begin(), s.end(), res) - fs;
				int valp = upper_bound(p.begin(), p.end(), res) - fp;

				valf--, vals--, valp--;

				if (valf + vals - valp == res - i) 
					l = res;
				else
					r = res;
			}

			if (l < N - 1)
				d[i] = l + 1;
		}*/
	}	

	tmp.resize(N);
	for (int i = 0; i < N; i++)
		tmp[i] = d[i];
	st.init(tmp);

	for (int i = 0; i < K; i++) {
		if (N2[i] - N1[i] <= MAGIC) {
			int val = -1;
			for (int j = N1[i]; j < N2[i]; j++) {
				if (d[j] <= N2[i]) {
					val = j;
					break;
				}
			}
			if (val != -1) {
				printf("%d %d\n", val + 1, d[val] + 1);
			} else {
				puts("0 0");
			}
		} else {
			int val = st.getMin(N1[i] + 1, N2[i] + 1);
			if (st.get(val) <= N2[i]) {
				printf("%d %d\n", val + 1, st.get(val) + 1);
			} else {
				puts("0 0");
			}
		}
	}
}

int main() {
	freopen("mosaic.in", "r", stdin);
	//freopen("input.txt", "r", stdin);
	freopen("mosaic.out", "w", stdout);
	scanf("%d", &N);
	for (int i = 0; i < N; i++)
		scanf("%d%d", &A[i], &B[i]);
	scanf("%d", &K);
	for (int i = 0; i < K; i++) {
		scanf("%d%d", &N1[i], &N2[i]);
		N1[i]--, N2[i]--;
	}

	/*if (N <= 5000 && K <= 5000) {
		foolSolution();
		return 0;
	} else {
		cleverSolution();
		return 0;
	}*/
	cleverSolution();
	return 0;	
}