#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <string>
#include <cstring>
#include <algorithm>
#include <ctime>
#include <cmath>

using namespace std;

#pragma comment(linker, "/STACK:268435456")

struct tree
{
	tree *l, *r;
	int x, y;
	int size;

	tree(int _x)
	{
		size = 1;
		x = _x;
		y = rand();
		l = r = 0;
	}
};

typedef tree* ptree;

inline int si(ptree root)
{
	if (root)
		return root->size;
	return 0;
}

inline void update(ptree root)
{
	if (!root)
		return;
	root->size = si(root->l) + si(root->r) + 1;
};

void split(ptree root, ptree &l, ptree &r, int key)
{
	if (!root)
		return void(l=r=0);
	if (root->x >= key)
	{
		split(root->l, l, root->l, key);
		r = root;
	}
	else
	{
		split(root->r, root->r, r, key);
		l = root;
	}
	update(l);
	update(r);
};

ptree merge(ptree l, ptree r)
{
	if (!l)
		return r;
	if (!r)
		return l;

	if (l->y > r->y)
	{
		l->r = merge(l->r, r);
		update(l);
		return l;
	}
	else
	{
		r->l = merge(l, r->l);
		update(r);
		return r;
	}
};

inline void insert(ptree &root, int key)
{
	ptree q, w;
	ptree t = new tree(key);
	split(root, q, w, key);
	root = merge(merge(q, t), w);
};

inline void erase(ptree &root, int key)
{
	ptree q, t, w, r;
	split(root, q, r, key);
	split(r, t, w, key+1);
	root = merge(q, w);
};

inline int getMoreThanTree(ptree root, int key)
{
	ptree q, w;
	split(root, q, w, key+1);
	int res = si(w);
	root = merge(q, w);
	return res;
};

struct RMQ
{
	static const int l1 = 1<<18;
	static const int l2 = l1*2-1;

	ptree el[l2];


	RMQ()
	{
		memset(el, 0, sizeof(el));
	};

	inline void setValue(int x, int value)
	{
		x += l1-1;
		while (x>=0)
		{
			insert(el[x], value);
			x = (x+1)/2-1;
		}
	};

	inline void deleteValue(int x, int value)
	{
		x += l1-1;
		while (x>=0)
		{
			erase(el[x], value);
			x = (x+1)/2-1;
		}
	}

	inline int getMoreThan(int l, int r, int key)
	{
		int res = 0;
		l += l1-1;
		r += l1-1;

		while (l <= r)
		{
			if (l % 2 == 0)
			{
				res += getMoreThanTree(el[l], key);
				l++;
			}
			
			if (r%2 == 1)
			{
				res += getMoreThanTree(el[r], key);
				r--;
			}

			l = (l+1)/2-1;
			r = (r+1)/2-1;
		}
		return res;
	}
};

struct edge
{
	int x;
	edge* next;
};

inline void AddEdge(vector<edge*> &E, int a, int b)
{
	edge* t = new edge;
	t->x = b;
	t->next = E[a];
	E[a] = t;
}

vector< edge* > E1;
vector< edge* > E2;

int curtime = 0;
vector< int > inTime2;
vector< int > outTime2;

void DFStime(int x, int pred)
{
	inTime2[x] = curtime++;
	for (edge* e  = E2[x]; e; e=e->next)
		if (e->x != pred)
		{
			DFStime(e->x, x);
		}
	outTime2[x] = curtime++;
}

RMQ Q;

int n;
int firstboss;
int secondboss;

long long answer = 0;


void DFS(int x, int pred)
{
	answer += Q.getMoreThan(0, inTime2[x]-1, outTime2[x]);
	Q.setValue(inTime2[x], outTime2[x]);

	for (edge* e = E1[x]; e; e=e->next)
		if (e->x != pred)
		{
			DFS(e->x, x);
		}

	Q.deleteValue(inTime2[x], outTime2[x]);
};


int main()
{
	freopen("virus.in","r", stdin);
	freopen("virus.out","w", stdout);
	scanf("%d", &n);

	E1.assign(n, (edge*) 0);
	for (int i = 0; i < n; i++)
	{
		int pred;
		scanf("%d", &pred);
		pred--;
		if (pred != -1)
			AddEdge(E1, pred, i);
		else
			firstboss = i;
	}

	E2.assign(n, (edge*) 0);
	for (int i =0 ;i < n; i++)
	{
		int pred;
		scanf("%d", &pred);
		pred--;
		if (pred != -1)
			AddEdge(E2, pred, i);
		else
			secondboss = i;
	}

	inTime2.resize(n);
	outTime2.resize(n);
	DFStime(secondboss, -1);

	DFS(firstboss, -1);

	cout << answer;
}