#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <string>
#include <cstring>
#include <algorithm>
#include <ctime>
#include <cmath>

using namespace std;

#pragma comment(linker, "/STACK:268435456")

struct tree
{
	tree *l, *r;
	int x, y;
	int size;

	tree(int _x, int _y)
	{
		size = 1;
		x = _x;
		y = _y;
		l = r = 0;
	}
};

typedef tree* ptree;

inline int si(ptree root)
{
	if (root)
		return root->size;
	return 0;
}

void split(ptree root, ptree &l, ptree &r, int key)
{
	if (!root)
		return void(l=r=0);
	if (root->x >= key)
	{
		split(root->l, l, root->l, key);
		r = root;
	}
	else
	{
		split(root->r, root->r, r, key);
		l = root;
	}

	if (l)
	{
		l->size = si(l->l) + si(l->r) + 1;
	}
	if (r)
	{
		r->size = si(r->l) + si(r->r) + 1;
	}
};

ptree merge(ptree l, ptree r)
{
	if (!l)
		return r;
	if (!r)
		return l;

	if (l->y > r->y)
	{
		l->r = merge(l->r, r);
		if (l)
		{
			l->size = si(l->l) + si(l->r) + 1;
		}
		return l;
	}
	else
	{
		r->l = merge(l, r->l);
		if (r)
		{
			r->size = si(r->l) + si(r->r) + 1;
		}
		return r;
	}
};

inline void insert(ptree &root, int key, int _y)
{
	if (!root)
	{
		root = new tree(key, _y);
		return;
	}
	
	if (root->y < _y)
	{
		ptree q = new tree(key, _y);
		split(root, q->l, q->r, key);
		root = q;
		return;
	}

	if (root->x >= key)
		insert(root->l, key, _y);
	else
		insert(root->r, key, _y);
	
	if (root)
	{
		root->size = si(root->l) + si(root->r) + 1;
	}
};

inline void erase(ptree &root, int key)
{
	if (!root)
		return;

	if (root->x == key)
	{
		root = merge(root->l, root->r);
		return;
	}

	if (root->x > key)
		erase(root->l, key);
	else
		erase(root->r, key);
	
	if (root)
	{
		root->size = si(root->l) + si(root->r) + 1;
	}
};

inline int getMoreThanTree(ptree root, int key)
{
	if (!root)
		return 0;

	int res = 0;
	if (root->x > key)
		++res;

	if (root->x >= key)
	{
		res += si(root->r);
		res += getMoreThanTree(root->l, key);
	}
	else
	{
		res += getMoreThanTree(root->r, key);
	}

	return res;
};

struct RMQ
{
	static const int l1 = 1<<17;
	static const int l2 = l1*2-1;

	ptree el[l2];

	RMQ()
	{
		memset(el, 0, sizeof(el));
	};

	inline void setValue(int x, int value)
	{
		x += l1-1;
		int _y = rand();
		while (x>=0)
		{
			insert(el[x], value, _y);
			x = (x+1)/2-1;
		}
	};

	inline void deleteValue(int x, int value)
	{
		x += l1-1;
		while (x>=0)
		{
			erase(el[x], value);
			x = (x+1)/2-1;
		}
	}

	inline int getMoreThan(int l, int r, int key)
	{
		int res = 0;
		l += l1-1;
		r += l1-1;

		while (l <= r)
		{
			if (l & 1 == 0)
			{
				res += getMoreThanTree(el[l], key);
				++l;
			}
			
			if (r & 1 == 1)
			{
				res += getMoreThanTree(el[r], key);
				--r;
			}

			l = ((l+1)>>1)-1;
			r = ((r+1)>>1)-1;
		}
		return res;
	}
};

struct edge
{
	edge* next;
	int x;
};

const int MAXN = 100001;

edge* E1[MAXN];
edge* E2[MAXN];

int curtimein = 0;
int curtimeout = 0;
int inTime2[MAXN];
int outTime2[MAXN];

void DFStime(int x)
{
	inTime2[x] = ++curtimein;
	for (edge* e = E2[x]; e; e=e->next)
	{
		DFStime(e->x);
	}
	outTime2[x] = ++curtimeout;
}

RMQ Q;

int n;
int firstboss;
int secondboss;

long long answer = 0;

void DFS(int x)
{
//	fprintf(stderr, "%d\n", x);
	answer += Q.getMoreThan(0, inTime2[x]-1, outTime2[x]);
	Q.setValue(inTime2[x], outTime2[x]);

	for (edge* e  =E1[x]; e; e=e->next)
	{
		DFS(e->x);
	}

	Q.deleteValue(inTime2[x], outTime2[x]);
};


int main()
{
	double start = clock();
	freopen("virus.in","r", stdin);
	freopen("virus.out","w", stdout);
	scanf("%d", &n);

	memset(E1, 0, sizeof(E1));
	for (int i = 0; i < n; ++i)
	{
		int pred;
		scanf("%d", &pred);
		pred--;
		if (pred != -1)
		{
			edge* t = new edge;
			t->x = i;
			t->next = E1[pred];
			E1[pred] = t;
		}
		else
			firstboss = i;
	}

	memset(E2, 0, sizeof(E2));
	for (int i =0 ;i < n; ++i)
	{
		int pred;
		scanf("%d", &pred);
		pred--;
		if (pred != -1)
		{
			edge* t = new edge;
			t->x = i;
			t->next = E2[pred];
			E2[pred] = t;
		}
		else
			secondboss = i;
	}

	DFStime(secondboss);
	DFS(firstboss);

	cerr << (clock()-start) / CLOCKS_PER_SEC << endl;

	printf("%I64d", answer);

	return 0;
}