
#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <string>
#include <cstring>
#include <algorithm>
#include <ctime>
#include <cmath>
 
using namespace std;
 
#pragma comment(linker, "/STACK:268435456")


struct tree
{
    int l, r;
    int x, y;
    int size;
};

int TSIZE = 1;
tree MEM[10800000];

typedef int ptree;
inline int getNew(int key, int y)
{
	ptree cur = TSIZE++;
	MEM[cur].l = 0;
	MEM[cur].r = 0;
	MEM[cur].size = 1;
	MEM[cur].x = key;
	MEM[cur].y = y;
	return cur;
}

 
inline int si(ptree root)
{
    if (root)
        return MEM[root].size;
    return 0;
}
 
void split(ptree root, ptree &l, ptree &r, int key)
{
    if (!root)
        return void(l=r=0);
    if (MEM[root].x >= key)
    {
        split(MEM[root].l, l, MEM[root].l, key);
        r = root;
    }
    else
    {
        split(MEM[root].r, MEM[root].r, r, key);
        l = root;
    }
 
    if (l)
    {
        MEM[l].size = si(MEM[l].l) + si(MEM[l].r) + 1;
    }
    if (r)
    {
        MEM[r].size = si(MEM[r].l) + si(MEM[r].r) + 1;
    }
};
 
ptree merge(ptree l, ptree r)
{
    if (!l)
        return r;
    if (!r)
        return l;
 
    if (MEM[l].y > MEM[r].y)
    {
        MEM[l].r = merge(MEM[l].r, r);
        if (l)
        {
            MEM[l].size = si(MEM[l].l) + si(MEM[l].r) + 1;
        }
        return l;
    }
    else
    {
        MEM[r].l = merge(l, MEM[r].l);
        if (r)
        {
            MEM[r].size = si(MEM[r].l) + si(MEM[r].r) + 1;
        }
        return r;
    }
};
 
inline void insert(ptree &root, int key, int _y)
{
    if (!root)
    {
        root = getNew(key, _y);
        return;
    }
     
    if (MEM[root].y < _y)
    {
        ptree q = getNew(key, _y);
        split(root, MEM[q].l, MEM[q].r, key);
        root = q;
        return;
    }
 
    if (MEM[root].x >= key)
        insert(MEM[root].l, key, _y);
    else
        insert(MEM[root].r, key, _y);
     
    if (root)
    {
        MEM[root].size = si(MEM[root].l) + si(MEM[root].r) + 1;
    }
};
 
inline void erase(ptree &root, int key)
{
    if (!root)
        return;
 
    if (MEM[root].x == key)
    {
        root = merge(MEM[root].l, MEM[root].r);
        return;
    }
 
    if (MEM[root].x > key)
        erase(MEM[root].l, key);
    else
        erase(MEM[root].r, key);
     
    if (root)
    {
        MEM[root].size = si(MEM[root].l) + si(MEM[root].r) + 1;
    }
};
 
inline int getMoreThanTree(ptree root, int key)
{
    if (!root)
        return 0;
 
    int res = 0;
 
    ptree cur = root;
 
    while (cur)
    {
        if (MEM[cur].x > key)
            ++res;
 
        if (MEM[cur].x >= key)
        {
            res += si(MEM[cur].r);
            cur = MEM[cur].l;
        }
        else
        {
            cur = MEM[cur].r;
        }
    }
 
    return res;
};
 
struct RMQ
{
    static const int l1 = 1<<17;
    static const int l2 = l1*2-1;
 
    ptree el[l2];
 
    RMQ()
    {
        memset(el, 0, sizeof(el));
    };
 
    inline void setValue(int x, int value)
    {
        x += l1-1;
        int _y = rand();
        while (x>=0)
        {
            insert(el[x], value, _y);
            x = (x+1)/2-1;
        }
    };
 
    inline void deleteValue(int x, int value)
    {
        x += l1-1;
        while (x>=0)
        {
            erase(el[x], value);
            x = (x+1)/2-1;
        }
    }
 
    inline int getMoreThan(int l, int r, int key)
    {
        int res = 0;
        l += l1-1;
        r += l1-1;
 
        while (l <= r)
        {
            if (l & 1 == 0)
            {
                res += getMoreThanTree(el[l], key);
                ++l;
            }
             
            if (r & 1 == 1)
            {
                res += getMoreThanTree(el[r], key);
                --r;
            }
 
            l = ((l+1)>>1)-1;
            r = ((r+1)>>1)-1;
        }
        return res;
    }
};
 
struct edge
{
    edge* next;
    int x;
};
 
const int MAXN = 100001;
 
edge* E1[MAXN];
edge* E2[MAXN];
 
int curtimein = 0;
int curtimeout = 0;
int inTime2[MAXN];
int outTime2[MAXN];
 
void DFStime(int x)
{
    inTime2[x] = ++curtimein;
    for (edge* e = E2[x]; e; e=e->next)
    {
        DFStime(e->x);
    }
    outTime2[x] = ++curtimeout;
}
 
RMQ Q;
 
int n;
int firstboss;
int secondboss;
 
long long answer = 0;
 
void DFS(int x)
{
//  fprintf(stderr, "%d\n", x);
    answer += Q.getMoreThan(0, inTime2[x]-1, outTime2[x]);
    Q.setValue(inTime2[x], outTime2[x]);
 
    for (edge* e  =E1[x]; e; e=e->next)
    {
        DFS(e->x);
    }
 
    Q.deleteValue(inTime2[x], outTime2[x]);
};
 
 
int main()
{
   // double start = clock();
    freopen("virus.in","rb", stdin);
    freopen("virus.out","wb", stdout);
    scanf("%d", &n);

	
    memset(E1, 0, sizeof(E1));
    for (int i = 0; i < n; ++i)
    {
        int pred;
        scanf("%d", &pred);
        pred--;
        if (pred != -1)
        {
            edge* t = new edge;
            t->x = i;
            t->next = E1[pred];
            E1[pred] = t;
        }
        else
            firstboss = i;
    }
 
    memset(E2, 0, sizeof(E2));
    for (int i =0 ;i < n; ++i)
    {
        int pred;
        scanf("%d", &pred);
        pred--;
        if (pred != -1)
        {
            edge* t = new edge;
            t->x = i;
            t->next = E2[pred];
            E2[pred] = t;
        }
        else
            secondboss = i;
    }
 
    DFStime(secondboss);
    DFS(firstboss);
 
   // cerr << (clock()-start) / CLOCKS_PER_SEC << endl;
 
    printf("%I64d", answer);
 
    return 0;
}