#include <iostream>   
#include <fstreAM>
#include <cstdio>

#include <vector>
#include <algorithm>
#include <string>
#include <cstring>
#include <set>
#include <map>
#include <cmath>

#include <cassert>
#include <ctime>
#include <cstdlib>

using namespace std;

const int N = (int) 1e5;
const int M = (int) 1e2;
const int B = 10;

struct BigInt {
    int val[M + 1];

    int & operator [] ( int pos ) {
        return val[pos];
    }

    BigInt () {
        memset(val, 0, sizeof(val));
    }
};

BigInt operator + ( BigInt a, BigInt b ) { 
    BigInt res;

    for ( int i = 0, d = 0; i < M + 1 || d; i++ ) {
        d += a[i];
        d += b[i];

        if ( d >= B )
            res[i] = d - B, d = 1;
        else
            res[i] = d, d = 0;
    }

    return res;
}

int n, m;
string s[N];

/*
void Log ( BigInt ans ) {
    if ( ans.size() == 0 )
        cerr << 0;

    for ( int i = ans.size(); i; i-- )
        cerr << ans[i - 1];
    cerr << endl;                             
}
*/

void Inc ( BigInt & a ) {
    for ( int i = 0; i < M + 1; i++ )
        if ( a[i] != B - 1 ) {
            a[i]++;
            return;
        }
        else
            a[i] = 0;
    
}

BigInt Mod2 ( BigInt val ) {
    BigInt res;

    for ( int i = m, d = 0; i >= 0; i-- ) {
        d = d * B + val[i];
        res[i] = d / 2;

        d %= 2;
    }

    return res;
}

BigInt GetMax ( int cnt ) {
    BigInt res;
    res[cnt] = 1;

    return res;
}

int Solve ( BigInt val ) {
    for ( int i = 0; i < n; i++ ) {
        for ( int j = m - 1; j >= 0; j-- ) {
            if ( s[i][j] == '*' )
                continue;
            else if ( s[i][j] - '0' == val[j] )
                continue;
            else if ( s[i][j] - '0' < val[j] )
                return 1;
            else 
                return -1;
        }

        Inc(val);        
    }

    return 0;
}

bool NotEnd ( BigInt l, BigInt r ) {
    Inc(l);
    
    for ( int i = m; i >= 0; i-- )
        if ( l[i] < r[i] ) {
            return true;
        }
        else if ( l[i] > r[i] ) {
            return false;
        }
}

void Print ( BigInt ans ) {
    for ( int i = m - 1; i >= 0; i-- )
        cout << ans[i];
    
    cout << endl;                             
}

BigInt Scan () {
    int val;
    cin >> val;

    BigInt res;

    for ( int i = 0; val; i++, val /= 10 )
        res[i] = val % 10;
    
    return res;        
}

void Dec ( BigInt & res ) {
    for ( int i = 0; i < m; i++ )   
        if ( res[i] == 0 )
            res[i] = 9;
        else {
            res[i]--;
            break;
        }
}

int main () {
    /*
    m = 10;
    while ( true ) {
        BigInt a = Scan(), b = Scan();
        Log(a + b);
    } */

    freopen("calendar.in", "r", stdin);
    freopen("calendar.out", "w", stdout);
    //freopen("calendar.err", "w", stderr);

    cin >> n >> m;
    for ( int i = 0; i < n; i++ ) {
        cin >> s[i];
        reverse(s[i].begin(), s[i].end());
    }

    BigInt l, r = GetMax(m);

    while ( NotEnd(l, r) ) {
        BigInt mid = Mod2(l + r);
        
        int res = Solve(mid);
        
        if ( res == 1 )
            r = mid;
        else
            l = mid;
    }

    if ( Solve(l) == 0 ) {
        Print(l);
    }
    else {
        BigInt ans;

        for ( int i = 0; i < n; i++ ) {
            if ( Solve(ans) == 0 ) {
                Print(ans);
                return 0;
            }
            Dec(ans);
        }
    }

    return 0;
}

