#include <iostream>   
#include <fstreAM>
#include <cstdio>

#include <vector>
#include <algorithm>
#include <string>
#include <cstring>
#include <set>
#include <map>
#include <cmath>

#include <cassert>
#include <ctime>
#include <cstdlib>

using namespace std;

typedef vector <int> BigInt;

const int N = (int) 1e5;
const int B = 10;

BigInt operator + ( BigInt a, BigInt b ) { 
    BigInt res(max(a.size(), b.size()) + 1);

    for ( int i = 0, d = 0; i < max(a.size(), b.size()) || d; i++ ) {
        if ( i < a.size() )
            d += a[i];
        if ( i < b.size() )
            d += b[i];

        if ( d >= B )
            res[i] = d - B, d = 1;
        else
            res[i] = d, d = 0;
    }

    while ( res.size() && !res.back() )
        res.pop_back();

    return res;
}

int n, m;
string s[N];

void Log ( BigInt ans ) {
    if ( ans.size() == 0 )
        cerr << 0;

    for ( int i = ans.size(); i; i-- )
        cerr << ans[i - 1];
    cerr << endl;                             
}


void Inc ( BigInt & a ) {
    for ( int i = 0; i < a.size(); i++ )
        if ( a[i] != B - 1 ) {
            a[i]++;
            return;
        }
        else
            a[i] = 0;

    a.push_back(1);

    if ( a.size() > m )
        a.resize(0);
}

BigInt Mod2 ( BigInt val ) {
    BigInt res(val.size());

    for ( int i = val.size(), d = 0; i; i-- ) {
        d = d * B + val[i - 1];
        res[i - 1] = d / 2;

        d %= 2;
    }

    while ( res.size() && !res.back() )
        res.pop_back();

    return res;
}

BigInt GetMax ( int cnt ) {
    BigInt res(cnt + 1);
    res[cnt] = 1;

    return res;
}

int Solve ( BigInt val ) {
    for ( int i = 0; i < n; i++ ) {
        for ( int j = m - 1; j >= 0; j-- ) {
            if ( s[i][j] == '*' )
                continue;
            if ( val.size() > j ) {
                if ( s[i][j] - '0' == val[j] )
                    continue;
                else if ( s[i][j] - '0' < val[j] )
                    return 1;
                else 
                    return -1;
            }
            else {
                if ( s[i][j] - '0' == 0 )
                    continue;
                 else
                        return -1;
            }
        }

        Inc(val);        
    }

    return 0;
}

bool NotEnd ( BigInt l, BigInt r ) {
    Inc(l);
    
    if ( l.size() < r.size() ) {
        return true;
    }
    else if ( l.size() == r.size() ) {
        for ( int i = l.size() - 1; i >= 0; i-- )
            if ( l[i] < r[i] ) {
                return true;
            }
            else if ( l[i] > r[i] ) {
                return false;
            }

        return false;
    }
    else {
        return false;
    }
}

void Print ( BigInt ans ) {
    for ( int i = m - 1; i >= 0; i-- )
        if ( ans.size() > i )
            cout << ans[i];
        else
            cout << 0;
    cout << endl;                             
}

BigInt Scan () {
    int val;
    cin >> val;

    BigInt res;

    while ( val )
        res.push_back(val % 10), val /= 10;

    return res;        
}

void Dec ( BigInt & res ) {
    res.resize(m);

    for ( int i = 0; i < res.size(); i++ )   
        if ( res[i] == 0 )
            res[i] = 9;
        else {
            res[i]--;
            break;
        }
}

int main () {
    /*
    m = 10;
    while ( true ) {
        BigInt a = Scan(), b = Scan();
        Log(a + b);
    } */

    freopen("calendar.in", "r", stdin);
    freopen("calendar.out", "w", stdout);
    //freopen("calendar.err", "w", stderr);

    cin >> n >> m;
    for ( int i = 0; i < n; i++ ) {
        cin >> s[i];
        reverse(s[i].begin(), s[i].end());
    }

    BigInt l(0), r = GetMax(m);

    while ( NotEnd(l, r) ) {
        BigInt mid = Mod2(l + r);
        
        /*
        Log(mid);
        Log(l);
        Log(r);
        cerr << endl;
        */

        int res = Solve(mid);
        
        if ( res == 1 )
            r = mid;
        else
            l = mid;
    }

    if ( Solve(l) == 0 ) {
        Print(l);
    }
    else {
        BigInt ans(0);

        for ( int i = 0; i < n; i++ ) {
            if ( Solve(ans) == 0 ) {
                Print(ans);
                return 0;
            }
            Dec(ans);
        }

        Print(l);
    }

    return 0;
}

