import java.util.*;
import java.io.*;

class teams_as {
    Scanner in;
    PrintWriter out;

    public class Graph {
        int n;
        List<Edge>[] edges;

        @SuppressWarnings("unchecked")
        public Graph(int n) {
            this.n = n;
            edges = new List[n];
            for (int i = 0; i < n; i++) {
                edges[i] = new ArrayList<Edge>();
            }
        }

        public void addEdge(int s, int d, int c, long p) {
            Edge ef = new Edge(s, d, c, p, 0);
            Edge er = new Edge(d, s, 0, -p, 0);
            ef.r = er;
            er.r = ef;
            edges[s].add(ef);
            edges[d].add(er);
        }

        long minCostFlow(int s, int t) {
            long[] d = new long[n];
            boolean[] u = new boolean[n];

            // Run Bellman-Ford algorithm
            d[s] = 0;
            u[s] = true;
            boolean changed = true;
            while (changed) {
                changed = false;
                for (int i = 0; i < n; i++) {
                    if (u[i]) {
                        for (Edge e: edges[i]) {
                            if (e.c > 0 && (!u[e.d] || d[e.d] > d[i] + e.p)) {
                                u[e.d] = true;
                                d[e.d] = d[i] + e.p;
                                changed = true;
                            }
                        }
                    }
                }
            }

            // Potentials
            long[] q = new long[n];
            for (int i = 0; i < n; i++) {
                q[i] = d[i];
            }

            long cost = 0;

            boolean[] v = new boolean[n];
            int[] c = new int[n];
            Edge[] from = new Edge[n];
            while (u[t]) {
                Arrays.fill(u, false);
                Arrays.fill(v, false);
                Arrays.fill(c, 0);

                // Run Dijkstra
                d[s] = 0;
                v[s] = true;
                c[s] = Integer.MAX_VALUE;

                while (!u[t]) {
                    int k = -1;
                    for (int j = 0; j < n; j++) {
                        if (!u[j] && v[j] && (k == -1 || d[j] < d[k])) {
                            k = j;
                        }
                    }
                    if (k == -1) {
                        break;
                    }

                    u[k] = true;
                    for (Edge e: edges[k]) {
                        if (e.c > e.f) {
                            if (!v[e.d] || d[e.d] > d[k] + e.p + q[e.s] - q[e.d]) {
                                v[e.d] = true;
                                d[e.d] = d[k] + e.p + q[e.s] - q[e.d];
                                c[e.d] = Math.min(c[k], e.c - e.f);
                                from[e.d] = e;
                            }
                        }
                    }
                }

                if (!u[t]) {
                    break;
                }

                for (int i = 0; i < n; i++) {
                    if (!u[i]) {
                        d[i] = d[t];
                    }
                }

                cost += (q[t] + d[t]) * c[t];

                int k = t;
                while (k != s) {
                    Edge e = from[k];
                    e.f += c[t];
                    e.r.f -= c[t];
                    k = e.s;
                }

                for (int i = 0; i < n; i++) {
                    q[i] += d[i];
                }
            }

            return cost;
        }
    }

    public class Edge {
        int s;
        int d;
        int c;
        long p;
        int f;
        Edge r;

        public Edge(int s, int d, int c, long p, int f) {
            this.s = s;
            this.d = d;
            this.c = c;
            this.p = p;
            this.f = f;
        }
    }

    public void solve() throws IOException {
        int n = in.nextInt();
        assert 1 <= n && n <= 100;
        int[] a = new int[2 * n];
        int[][] p = new int[n][2];
        for (int i = 0; i < n; i++) {
            Arrays.fill(p[i], -1);
        }
        for (int i = 0; i < 2 * n; i++) {
            a[i] = in.nextInt();
            assert 1 <= a[i] && a[i] <= n;
            a[i]--;
            if (p[a[i]][0] == -1) {
                p[a[i]][0] = i;
            } else {
                p[a[i]][1] = i;
            }
        }

        for (int i = 0; i < n; i++) {
            Arrays.sort(p[i]);
        }

        Graph g = new Graph(2 * n + 2);
        for (int i = 0; i < n; i++) {
            g.addEdge(2 * n, i, 1, 0);
            g.addEdge(i + n, 2 * n + 1, 1, 0);
            for (int j = 0; j < n; j++) {
                g.addEdge(i, j + n, 1, Math.abs(p[i][0] - j) + Math.abs(p[i][1] - (j + n)));
            }
        }
        g.minCostFlow(2 * n, 2 * n + 1);
        int[] b = new int[2 * n];
        for (int i = 0; i < n; i++) {
            for (Edge e : g.edges[i]) {
                if (e.f > 0) {
                    b[e.d - n] = i;
                    b[e.d] = i;
                }
            }
        }
        for (int i = 0; i < 2 * n; i++) {
            out.print((b[i] + 1) + " ");
        }
    }

    public void run() {
        try {
            in = new Scanner(new File("teams.in"));
            out = new PrintWriter(new File("teams.out"));

            solve();

            in.close();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static void main(String[] arg) {
        new teams_as().run();
    }
}