import java.io.*;
import java.util.*;

public class traffic_as_double_no_eps {
    FastScanner in;
    PrintWriter out;

    class Car {
        double a;
        double v;

        double t;
        double tM;

        int bucket;

        Car(double aD, double vD) {
            this.a = aD;
            this.v = vD;
        }
    }

    double x;

    void calcT(Car[] v) {
        double max = 0.0;
        Car prev = null;
        int buckN = 0;
        for (Car car : v) {
            double carT = car.a / car.v;
            if (carT > max) {
                max = carT;
            }
            car.t = max;
            car.tM = car.t % x;

            if (prev == null || Math.floor(car.t / x) != Math.floor(prev.t / x)) {
                buckN++;
            }
            car.bucket = buckN - 1;
            prev = car;
        }
    }

    class RMQ {
        int n;
        int[] v;

        RMQ(int n) {
            this.n = n;
            v = new int[4 * n];
        }

        public void update(int p, int d) {
            update(0, 0, n, p, d);
        }

        private void update(int i, int l, int r, int p, int d) {
            if (l == r - 1) {
                v[i] += d;
                return;
            }
            int m = (l + r) / 2;
            if (p < m) {
                update(2 * i + 1, l, m, p, d);
            } else {
                update(2 * i + 2, m, r, p, d);
            }
            v[i] = Math.max(v[2 * i + 1], v[2 * i + 2]);
        }

        public int max() {
            return v[0];
        }
    }

    public void solve() throws IOException {
        x = in.nextDouble();
        int n = in.nextInt();
        Car[] a = new Car[n];
        for (int i = 0; i < n; i++) {
            a[i] = new Car(in.nextDouble(), in.nextDouble());
        }
        Comparator<Car> compDist = new Comparator<Car>() {
            public int compare(Car o1, Car o2) {
                return o1.a < o2.a ? -1 : o1.a > o2.a ? 1 : 0;
            }
        };

        Arrays.sort(a, compDist);

        int m = in.nextInt();
        Car[] b = new Car[m];
        for (int i = 0; i < m; i++) {
            b[i] = new Car(in.nextDouble(), in.nextDouble());
        }
        Arrays.sort(b, compDist);

        calcT(a);
        calcT(b);

        Comparator<Car> compMod = new Comparator<Car>() {
            public int compare(Car o1, Car o2) {
                return o1.tM > o2.tM ? 1 : o1.tM < o2.tM ? -1 : 0;
            }
        };

        int abn = a[a.length - 1].bucket + 1;
        int bbn = b[b.length - 1].bucket + 1;
        RMQ armq = new RMQ(abn);
        RMQ brmq = new RMQ(bbn);
        for (Car c : a) {
            if (c.tM != 0) {
                armq.update(c.bucket, +1);
            }
        }

        int ans = armq.max();
        double optT = 0;

        Arrays.sort(a, compMod);
        Arrays.sort(b, compMod);

        int ap = 0;
        int bp = 0;

        while (ap < n || bp < m) {
            int aq = ap;
            int bq = bp;
            if (ap < n && (bp == m || a[ap].tM <= b[bp].tM)) {
                while (aq < n && a[ap].tM == a[aq].tM) {
                    if (a[aq].tM != 0) {
                        armq.update(a[aq].bucket, -1);
                    }
                    aq++;
                }
            }

            int v = Math.max(armq.max(), brmq.max());
            if (v < ans) {
                ans = v;
                if (ap < n && (bp == m || a[ap].tM <= b[bp].tM)) {
                    optT = a[ap].tM;
                } else {
                    optT = b[bp].tM;
                }
            }

            if (bp < m && (ap == n || b[bp].tM <= a[ap].tM)) {
                while (bq < m && b[bp].tM == b[bq].tM) {
                    if (b[bq].tM != 0) {
                        brmq.update(b[bq].bucket, +1);
                    }
                    bq++;
                }
            }

            ap = aq;
            bp = bq;
        }

        out.println(ans);
        double g = optT;
        out.println(g + " " + (x - g));
    }

    public void run() {
        try {
            in = new FastScanner(new File("traffic.in"));
            out = new PrintWriter(new File("traffic.out"));

            solve();

            in.close();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }


    public static void main(String[] arg) {
        Locale.setDefault(Locale.US);
        new traffic_as_double_no_eps().run();
    }

    class FastScanner {
        BufferedReader br;
        StringTokenizer st;

        FastScanner(File f) {
            try {
                br = new BufferedReader(new FileReader(f));
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
        }

        String next() {
            while (st == null || !st.hasMoreTokens()) {
                try {
                    st = new StringTokenizer(br.readLine());
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            return st.nextToken();
        }

        void close() throws IOException {
            br.close();
        }

        int nextInt() {
            return Integer.parseInt(next());
        }

        double nextDouble() {
            return Double.parseDouble(next());
        }
    }


}